/*
 * This file is part of libimlayouts
 *
 * Copyright (C) 2005 Nokia Corporation.
 *
 */

#ifndef __IMLAYOUT_VKB_H__
#define __IMLAYOUT_VKB_H__
G_BEGIN_DECLS
#include <glib.h>

#define VKB_VERSION 0
#define VKB_LAYOUT_DIR "/usr/share/keyboards"


typedef struct _IM_SPECIAL_KEY
{
  gint8 length;
  gint8 *scancodes;
} IM_SPECIAL_KEY;

typedef struct _IM_LABEL
{
  gint8 length;
  gchar *text;
} IM_LABEL;

typedef struct button_key
{
  unsigned short state;
  unsigned short type;
  IM_SPECIAL_KEY special;
  int init_x;
  int init_y;
  int end_x;
  int end_y;
  int timer;
} IM_BUTTON;

typedef enum {
  OSSO_VKB_LAYOUT_LOWERCASE = 0,
  OSSO_VKB_LAYOUT_UPPERCASE,
  OSSO_VKB_LAYOUT_SPECIAL
} vkb_layout_type;

typedef struct _vkb_scv_tab
{
  gchar *label;
  IM_LABEL *labels;
  IM_BUTTON *keys;
  gint num_keys;
  gint num_rows;
  gint num_columns;
} vkb_scv_tab;

typedef struct _vkb_layout
{
  vkb_layout_type type;
  IM_LABEL *labels;
  IM_BUTTON *keys;
  gint TOTAL_chars;

  gint8 num_rows;
  gint8 *num_keys_in_rows;
  gint8 baseline;
  gint8 *widths;

  gint num_tabs;
  vkb_scv_tab *tabs;
} vkb_layout;

/**
 * The data structure returned by #imlayout_vkb_load_file
 */
typedef struct _vkb_layout_collection
{
  vkb_layout       *collection; /**<Array of #vkb_layout */
  gint             num_layouts; /**<Number of available layout in this collection */
  vkb_layout_type  numeric_layout; /**<The type of layout of numeric layout */
  gchar            *name; /**<Localized name of this layout */
  gchar            *language; /**<Language code for this layout */
  gchar            *word_completion; /**<Word completion language code for this layout */
} vkb_layout_collection;

#define KEY_TYPE_ALPHA          0x01
#define KEY_TYPE_NUMERIC        0x02
#define KEY_TYPE_HEXA           0x04
#define KEY_TYPE_TELE           0x08
#define KEY_TYPE_SPECIAL        0x10
#define KEY_TYPE_DEAD           0x20
#define KEY_TYPE_WHITESPACE     0x40
#define KEY_TYPE_RAW            0x80

/**
 * This function return a layout collection available in a vkb file
 * @param filename the vkb file name in full path
 * @return the #vkb_layout_collection available in the file
 */
vkb_layout_collection *imlayout_vkb_load_file (const gchar *);

/**
 * This function frees the resources used in a layout collection.
 * @param collection the layout collection to be freed
 */
void imlayout_vkb_free_layout_collection (vkb_layout_collection *);

/**
 * This function returns the list of layout available on the system
 * @return a GList of the layout. Each entry is an array of string
 * with index 0 is the filename without the .vkb extension, index 1
 * is the localized name of the layout, index 2 is the language code,
 * index 3 is word completion language code
 */
GList *imlayout_vkb_get_layout_list ();

/**
 * This functions frees a list of layout available on the system
 * @param list the list containing the layout list returned by 
 * #imlayout_vkb_get_layout_list
 */
void imlayout_vkb_free_layout_list (GList *);


G_END_DECLS
#endif
